#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

# pylint: disable=C0116, R0903, W0406

""" Useful enums for workflows """
from enum import Enum


class WorkflowRequestState(Enum):
    """
    Enum that specifies the states a WorkflowRequest can find itself in
    """

    Complete = 0
    Created = 1
    Running = 2
    Failed = 3
    Paused = 4
    Error = -1


class ArchiveWorkflows(Enum):
    """
    Enum that specifies the workflows initiated from the AAT or VLASS
    """

    CARTA = "carta"
    SECI = "vlass_seci"
    CUBE = "vlass_coarse"
    QUICKLOOK = "vlass_quicklook"
    VLASS_CAL = "vlass_calibration"
    INGEST_SECI = "ingest_seci"

    @classmethod
    def values(cls):
        return cls._value2member_map_

    @classmethod
    def is_archive_wf(cls, wf_name: str):
        return wf_name in cls.values()
